summaryrefslogtreecommitdiff
path: root/src/console_cmds.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/console_cmds.cpp')
-rw-r--r--src/console_cmds.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/console_cmds.cpp b/src/console_cmds.cpp
index 0993bf47d..7f4463c2b 100644
--- a/src/console_cmds.cpp
+++ b/src/console_cmds.cpp
@@ -923,7 +923,7 @@ DEF_CONSOLE_CMD(ConNewGame)
return true;
}
-extern void SwitchMode(int new_mode);
+extern void SwitchToMode(SwitchMode new_mode);
DEF_CONSOLE_CMD(ConRestart)
{
@@ -933,10 +933,10 @@ DEF_CONSOLE_CMD(ConRestart)
return true;
}
/* Don't copy the _newgame pointers to the real pointers, so call SwitchMode directly */
_settings_game.game_creation.map_x = MapLogX();
_settings_game.game_creation.map_y = FindFirstBit(MapSizeY());
- SwitchMode(SM_NEWGAME);
+ SwitchToMode(SM_NEWGAME);
return true;
}
@@ -933,10 +933,10 @@ DEF_CONSOLE_CMD(ConRestart)
return true;
}
- /* Don't copy the _newgame pointers to the real pointers, so call SwitchMode directly */
+ /* Don't copy the _newgame pointers to the real pointers, so call SwitchToMode directly */
_settings_game.game_creation.map_x = MapLogX();
_settings_game.game_creation.map_y = FindFirstBit(MapSizeY());